@@ -14,7 +14,7 @@ verify_token_method = api_settings.VERIFY_METHOD
 
 
 class PlainTextParser(parsers.BaseParser):
-    media_type = "plain/text"
+    media_type = "text/plain"
     charset = "UTF-8"
 
     def parse(self, stream, media_type=None, parser_context=None):
